@@ -1,5 +1,5 @@
 from recette.steps import prep_step_dummy, prep_step_other
-from recette.utils import mix
+from recette.utils import combine
 
 # Package version single source of truth
-__version__ = "0.2.0"
+__version__ = "0.2.1"
